<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 * @return array An array of default values
 */

function firm_graphy_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$firm_graphy_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#181818',
		'header_tagline_color'			=> '#82868b',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'nav_search_enable'				=> true,
		'menu_type'						=> 'classic-menu',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'firm-graphy-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'firm-graphy-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'firm-graphy-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Banner,Services,About Us,Latest,Introduction,Event,Client,Testimonial,Blog,Counter,Featured Intro,Contact',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'firm-graphy-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,
		'archive_column'				=> 'col-2',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Banner
		'banner_section_enable'			=> true,
		'banner_content_type'			=> 'page',
		'banner_title'					=> esc_html__( 'We are here to help you!', 'firm-graphy-pro' ),
		'banner_description'			=> esc_html__( 'Beauty is a characteristic of an animal, idea, object, person or place that provides a perceptual experience of pleasure or satisfaction. And I believe in that.', 'firm-graphy-pro' ),
		'banner_btn_label'				=> esc_html__( 'Learn More', 'firm-graphy-pro' ),
		'alt_banner_btn_label'			=> esc_html__( 'Contact Us', 'firm-graphy-pro' ),
		'banner_address'				=> esc_html__( '1150 Kobenhavn United Kingdom', 'firm-graphy-pro' ),
		'banner_contact'				=> esc_html__( '+978-825-4631 katrina_ayuso@gmail.com', 'firm-graphy-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_column'				=> 'col-3',
		'service_title'					=> esc_html__( 'We are all here at your services for everything.', 'firm-graphy-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'About Us', 'firm-graphy-pro' ),
		'about_description'				=> sprintf( '%1$s <br> %2$s',  esc_html__( 'There is evidence that perceptions of beauty are evolutionary determined, that things, aspects of people and landscapes considered beautiful are typically found in situations likely to give enhanced survival of the perceiving human genes.', 'firm-graphy-pro' ), esc_html__( 'They also include less tangible advantages such as a confidence (not always warranted) that the system will be forgiving of your and your children mistakes, that your bad habits will not be seen as racial flaws, that portrayals of your race in the media and in history books will be mostly positive.', 'firm-graphy-pro' ) ),
		'about_btn_title'				=> esc_html__( 'Download Resume', 'firm-graphy-pro' ),

		// Latest
		'latest_section_enable'			=> true,
		'latest_count'					=> 4,
		'latest_content_type'			=> 'category',
		'latest_title'					=> esc_html__( 'Yes, we do work some time! View our latest work here.', 'firm-graphy-pro' ),

		// introduction
		'introduction_section_enable'	=> true,
		'introduction_content_type'		=> 'page',
		'introduction_title'			=> esc_html__( 'Meet our most creative team members', 'firm-graphy-pro' ),
		'introduction_description'		=> esc_html__( 'Beauty is a characteristic of an animal, idea, object, person or place that provides a perceptual experience of pleasure or satisfaction. And I believe in that.', 'firm-graphy-pro' ),
		'introduction_btn_label'		=> esc_html__( 'Explore Us', 'firm-graphy-pro' ),

		// event
		'event_section_enable'			=> true,
		'event_count'					=> 2,
		'event_content_type'			=> 'category',
		'event_title'					=> esc_html__( 'Our upcoming events for 2018', 'firm-graphy-pro' ),
		'event_description'				=> esc_html__( 'There is evidence that perceptions of beauty are evolutionary determine, that things, aspects of people and landscapes.', 'firm-graphy-pro' ),
		'event_btn_label'				=> esc_html__( 'Show All Upcoming Events ', 'firm-graphy-pro' ),

		// clients
		'client_section_enable'			=> true,
		'client_title'					=> esc_html__( 'We value our customer/clients above all others.', 'firm-graphy-pro' ),
		'client_content_type'			=> 'category',
		'client_count'					=> 6,

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_column'			=> 3,
		'testimonial_count'				=> 4,
		
		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Know what is happening around our circle of firm', 'firm-graphy-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Blogs', 'firm-graphy-pro' ),

		// Counter
		'counter_section_enable'		=> true,

		// featured intro
		'featured_intro_section_enable'	=> true,
		'featured_intro_content_type'	=> 'page',
		'featured_intro_title'			=> esc_html__( 'Choose us for the sake of beautiful web design', 'firm-graphy-pro' ),
		'featured_intro_description'	=> esc_html__( 'There is evidence that perceptions of beauty are evolutionary determined, that things, aspects of people and landscapes considered beautiful are typically found in situations likely to give enhanced survival of the perceiving human genes...', 'firm-graphy-pro' ),
		'featured_intro_btn_label'		=> esc_html__( 'Explore More', 'firm-graphy-pro' ),

		// Contact
		'contact_section_enable'		=> true,
		'contact_title'					=> esc_html__( 'Say Hello! to our team and stay connected with us', 'firm-graphy-pro' ),
		'contact_email'					=> 'noreply@themepalace.com',
		'contact_phone'					=> '+0 00 0000000',
		'contact_address'				=> esc_html__( '265 Street, Manbhawan, USA', 'firm-graphy-pro' ),
		'contact_website'				=> 'www.themepalace.com',

		
	);

	$output = apply_filters( 'firm_graphy_pro_default_theme_options', $firm_graphy_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}