<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'firm_graphy_pro_about_section', array(
	'title'             => esc_html__( 'About Us','firm-graphy-pro' ),
	'description'       => esc_html__( 'About Section options.', 'firm-graphy-pro' ),
	'panel'             => 'firm_graphy_pro_front_page_panel',
) );

// About content enable control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Switch_Control( $wp_customize, 'firm_graphy_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_about_section',
	'on_off_label' 		=> firm_graphy_pro_switch_options(),
) ) );

// About content type control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_select',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'firm_graphy_pro_is_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'firm-graphy-pro' ),
		'post' 		=> esc_html__( 'Post', 'firm-graphy-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'firm-graphy-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_about_section',
	'choices'			=> firm_graphy_pro_page_choices(),
	'active_callback'	=> 'firm_graphy_pro_is_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_content_post]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_about_section',
	'choices'			=> firm_graphy_pro_post_choices(),
	'active_callback'	=> 'firm_graphy_pro_is_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[about_title]', array(
	'label'           	=> esc_html__( 'Title', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_about_section',
	'active_callback' 	=> 'firm_graphy_pro_is_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[about_title]', array(
		'selector'            => '#skills .about-wrapper .entry-header h2.entry-title',
		'settings'            => 'firm_graphy_pro_theme_options[about_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_about_title_partial',
    ) );
}

// about description setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[about_description]', array(
	'label'           	=> esc_html__( 'Description', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_about_section',
	'active_callback' 	=> 'firm_graphy_pro_is_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[about_description]', array(
		'selector'            => '#skills .about-wrapper .entry-content',
		'settings'            => 'firm_graphy_pro_theme_options[about_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_about_description_partial',
    ) );
}

// about btn title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_about_section',
	'active_callback' 	=> 'firm_graphy_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[about_btn_title]', array(
		'selector'            => '#skills a.btn-primary',
		'settings'            => 'firm_graphy_pro_theme_options[about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_about_section',
	'active_callback' 	=> 'firm_graphy_pro_is_about_section_content_custom_enable',
	'type'				=> 'url',
) );

// about hr setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Customize_Horizontal_Line( $wp_customize, 'firm_graphy_pro_theme_options[about_hr]',
	array(
		'section'         => 'firm_graphy_pro_about_section',
		'active_callback' => 'firm_graphy_pro_is_about_section_enable',
		'type'			  => 'hr'
) ) );

// skills setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[about_skill]', array(
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[about_skill]', array(
	'label'           	=> esc_html__( 'Skill Shortcode', 'firm-graphy-pro' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins&plugin_status=install' ) ) . '" target="_blank"> %2$s </a> %3$s', esc_html__( 'Show your skills in horizontal line graph. Use shortcode from TP PieBuilder plugin. ', 'firm-graphy-pro' ), esc_html__( 'Click Here', 'firm-graphy-pro' ), esc_html__( 'to download.', 'firm-graphy-pro' ) ),
	'section'        	=> 'firm_graphy_pro_about_section',
	'active_callback' 	=> 'firm_graphy_pro_is_about_section_enable',
	'type'				=> 'textarea',
) );