<?php
/**
 * Contact Section options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'firm_graphy_pro_contact_section', array(
	'title'             => esc_html__( 'Contact','firm-graphy-pro' ),
	'description'       => esc_html__( 'Contact Section options.', 'firm-graphy-pro' ),
	'panel'             => 'firm_graphy_pro_front_page_panel',
) );

// Contact content enable control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[contact_section_enable]', array(
	'default'			=> 	$options['contact_section_enable'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Switch_Control( $wp_customize, 'firm_graphy_pro_theme_options[contact_section_enable]', array(
	'label'             => esc_html__( 'Contact Section Enable', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_contact_section',
	'on_off_label' 		=> firm_graphy_pro_switch_options(),
) ) );

// contact title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[contact_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[contact_title]', array(
	'label'           	=> esc_html__( 'Title', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_contact_section',
	'active_callback' 	=> 'firm_graphy_pro_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[contact_title]', array(
		'selector'            => '#contact-us .address-block .website span',
		'settings'            => 'firm_graphy_pro_theme_options[contact_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_contact_title_partial',
    ) );
}

// contact email setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[contact_email]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_email'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Multi_Input_Custom_Control( $wp_customize, 'firm_graphy_pro_theme_options[contact_email]', array(
	'label'             => esc_html__( 'Email ID', 'firm-graphy-pro' ),
	'button_text'       => esc_html__( 'Add Email ID.', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_contact_section',
	'active_callback' 	=> 'firm_graphy_pro_is_contact_section_enable',
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[contact_email]', array(
		'selector'            => '#contact-us .address-block .website span',
		'settings'            => 'firm_graphy_pro_theme_options[contact_email]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_contact_email_partial',
    ) );
}

// Contact phone control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[contact_phone]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_phone'],
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Multi_Input_Custom_Control( $wp_customize, 'firm_graphy_pro_theme_options[contact_phone]', array(
	'label'             => esc_html__( 'Phone No', 'firm-graphy-pro' ),
	'button_text'       => esc_html__( 'Add Phone No.', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_contact_section',
	'active_callback' 	=> 'firm_graphy_pro_is_contact_section_enable',
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[contact_phone]', array(
		'selector'            => '#contact-us .address-block .phone span',
		'settings'            => 'firm_graphy_pro_theme_options[contact_phone]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_contact_phone_partial',
    ) );
}

// Contact address setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[contact_address]', array(
	'sanitize_callback' => 'sanitize_textarea_field',
	'default'			=> $options['contact_address'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[contact_address]', array(
	'label'           	=> esc_html__( 'Address', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_contact_section',
	'active_callback' 	=> 'firm_graphy_pro_is_contact_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[contact_address]', array(
		'selector'            => '#contact-us .address-block .address span',
		'settings'            => 'firm_graphy_pro_theme_options[contact_address]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_contact_address_partial',
    ) );
}

// Contact website setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[contact_website]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['contact_website'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[contact_website]', array(
	'label'           	=> esc_html__( 'Website', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_contact_section',
	'active_callback' 	=> 'firm_graphy_pro_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[contact_website]', array(
		'selector'            => '#contact-us .address-block .website span',
		'settings'            => 'firm_graphy_pro_theme_options[contact_website]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_contact_website_partial',
    ) );
}

// Contact website setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[contact_form]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[contact_form]', array(
	'label'           	=> esc_html__( 'Contact Form', 'firm-graphy-pro' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins&plugin_status=install' ) ) . '" target="_blank"> %2$s </a> %3$s', esc_html__( 'To enable contact form. Use shortcode from Contact Form 7 plugin. ', 'firm-graphy-pro' ), esc_html__( 'Click Here', 'firm-graphy-pro' ), esc_html__( 'to download.', 'firm-graphy-pro' ) ),
	'section'        	=> 'firm_graphy_pro_contact_section',
	'active_callback' 	=> 'firm_graphy_pro_is_contact_section_enable',
	'type'				=> 'text',
) );