<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'firm_graphy_pro_event_section', array(
	'title'             => esc_html__( 'Event','firm-graphy-pro' ),
	'description'       => esc_html__( 'Event Section options.', 'firm-graphy-pro' ),
	'panel'             => 'firm_graphy_pro_front_page_panel',
) );

// Event content enable control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_section_enable]', array(
	'default'			=> 	$options['event_section_enable'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Firm_Graphy_Pro_Switch_Control( $wp_customize, 'firm_graphy_pro_theme_options[event_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_event_section',
	'on_off_label' 		=> firm_graphy_pro_switch_options(),
) ) );

// event title setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[event_title]', array(
	'label'           	=> esc_html__( 'Title', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_event_section',
	'active_callback' 	=> 'firm_graphy_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[event_title]', array(
		'selector'            => '#education .section-header h2.section-title',
		'settings'            => 'firm_graphy_pro_theme_options[event_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_event_title_partial',
    ) );
}

// event description setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_description]', array(
	'sanitize_callback' => 'sanitize_textarea_field',
	'default'			=> $options['event_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[event_description]', array(
	'label'           	=> esc_html__( 'Description', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_event_section',
	'active_callback' 	=> 'firm_graphy_pro_is_event_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[event_description]', array(
		'selector'            => '#education .entry-container .section-content p',
		'settings'            => 'firm_graphy_pro_theme_options[event_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_event_description_partial',
    ) );
}

// event number control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_count]', array(
	'default'          	=> $options['event_count'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_number_range',
	'validate_callback' => 'firm_graphy_pro_validate_event_count',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[event_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'firm-graphy-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_event_section',
	'active_callback'   => 'firm_graphy_pro_is_event_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 4,
		'style' => 'width: 100px;'
		),
) );

// event image setting and control.
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_image]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'firm_graphy_pro_theme_options[event_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'firm-graphy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'firm-graphy-pro' ), 520, 717 ),
		'section'     		=> 'firm_graphy_pro_event_section',
		'active_callback'	=> 'firm_graphy_pro_is_event_section_enable',
) ) );

// Event content type control and setting
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_content_type]', array(
	'default'          	=> $options['event_content_type'],
	'sanitize_callback' => 'firm_graphy_pro_sanitize_select',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[event_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_event_section',
	'type'				=> 'select',
	'active_callback' 	=> 'firm_graphy_pro_is_event_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'firm-graphy-pro' ),
		'post' 		=> esc_html__( 'Post', 'firm-graphy-pro' ),
		'category' 	=> esc_html__( 'Category', 'firm-graphy-pro' ),
	),
) );

for ( $i = 1; $i <= $options['event_count']; $i++ ) :
	// event pages drop down chooser control and setting
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_content_page_' . $i . ']', array(
		'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[event_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'firm-graphy-pro' ), $i ),
		'section'           => 'firm_graphy_pro_event_section',
		'choices'			=> firm_graphy_pro_page_choices(),
		'active_callback'	=> 'firm_graphy_pro_is_event_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_content_post_' . $i . ']', array(
		'sanitize_callback' => 'firm_graphy_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Chooser( $wp_customize, 'firm_graphy_pro_theme_options[event_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'firm-graphy-pro' ), $i ),
		'section'           => 'firm_graphy_pro_event_section',
		'choices'			=> firm_graphy_pro_post_choices(),
		'active_callback'	=> 'firm_graphy_pro_is_event_section_content_post_enable',
	) ) );

	// event date setting and control
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_date_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'firm_graphy_pro_theme_options[event_date_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'From-To %d', 'firm-graphy-pro' ), $i ),
		'section'        	=> 'firm_graphy_pro_event_section',
		'active_callback' 	=> 'firm_graphy_pro_is_event_section_enable',
		'type'				=> 'text',
	) );

	// event hr setting and control
	$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Firm_Graphy_Pro_Customize_Horizontal_Line( $wp_customize, 'firm_graphy_pro_theme_options[event_hr_'. $i .']',
		array(
			'section'         => 'firm_graphy_pro_event_section',
			'active_callback' => 'firm_graphy_pro_is_event_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'firm_graphy_pro_theme_options[event_content_category]', array(
	'sanitize_callback' => 'firm_graphy_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Firm_Graphy_Pro_Dropdown_Taxonomies_Control( $wp_customize,'firm_graphy_pro_theme_options[event_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'firm-graphy-pro' ),
	'description'      	=> esc_html__( 'Note: Event selected no of posts will be shown from selected category', 'firm-graphy-pro' ),
	'section'           => 'firm_graphy_pro_event_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'firm_graphy_pro_is_event_section_content_category_enable'
) ) );

// event btn label setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['event_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[event_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_event_section',
	'active_callback' 	=> 'firm_graphy_pro_is_event_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'firm_graphy_pro_theme_options[event_btn_label]', array(
		'selector'            => '#education .entry-container a.btn-primary',
		'settings'            => 'firm_graphy_pro_theme_options[event_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'firm_graphy_pro_event_btn_label_partial',
    ) );
}

// event btn link setting and control
$wp_customize->add_setting( 'firm_graphy_pro_theme_options[event_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'firm_graphy_pro_theme_options[event_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'firm-graphy-pro' ),
	'section'        	=> 'firm_graphy_pro_event_section',
	'active_callback' 	=> 'firm_graphy_pro_is_event_section_enable',
	'type'				=> 'url',
) );