<?php
/**
 * Contact section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage Firm Graphy Pro
 * @since Firm Graphy Pro 1.0.0
 */
if ( ! function_exists( 'firm_graphy_pro_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since Firm Graphy Pro 1.0.0
    */
    function firm_graphy_pro_add_contact_section() {
    	$options = firm_graphy_pro_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'firm_graphy_pro_section_status', true, 'contact_section_enable' );

        if ( true !== $contact_enable ) {
            return false;
        }

        // Render contact section now.
        firm_graphy_pro_render_contact_section();
    }
endif;

if ( ! function_exists( 'firm_graphy_pro_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since Firm Graphy Pro 1.0.0
   *
   */
   function firm_graphy_pro_render_contact_section() {
        $options = firm_graphy_pro_get_theme_options();
        $contact_phone = ! empty( $options['contact_phone'] ) ? explode( '|', $options['contact_phone'] ) : array();
        $contact_email = ! empty( $options['contact_email'] ) ? explode( '|', $options['contact_email'] ) : array();
        ?>

        <div id="contact-us" class="relative page-section no-padding-top">
                <div class="wrapper">
                    <div class="section-content col-2">
                         <div class="hentry">
                            <div class="contact-description">
                                <?php if ( ! empty( $options['contact_title'] ) ) : ?>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $options['contact_title'] ); ?></h2>
                                    </header>
                                <?php endif; ?>

                                <div class="entry-content">
                                    <ul class="address-block">
                                        <?php if ( ! empty( $options['contact_email'] ) ) : ?>
                                             <li class="email"><label><?php esc_html_e( 'Email:', 'firm-graphy-pro' ); ?></label>
                                                 <?php foreach ( $contact_email as $email ) : ?>
                                                    <span><a href="mailto:<?php echo esc_attr( $email ); ?>"><?php echo esc_html( $email ); ?></a></span>
                                                <?php endforeach; ?>
                                            </li>
                                        <?php endif; 

                                        if ( ! empty( $options['contact_phone'] ) ) : ?>
                                            <li class="phone"><label><?php esc_html_e( 'Call Us:', 'firm-graphy-pro' ); ?></label>
                                                 <?php foreach ( $contact_phone as $phone ) : ?>
                                                    <span><a href="tel:<?php echo esc_attr( $phone ); ?>"><?php echo esc_html( $phone ); ?></a></span>
                                                <?php endforeach; ?>
                                            </li>
                                        <?php endif; 

                                        if ( ! empty( $options['contact_address'] ) ) : ?>
                                            <li class="address"><label><?php esc_html_e( 'Address:', 'firm-graphy-pro' ); ?></label>
                                                <span><?php echo esc_html( $options['contact_address'] ); ?></span>
                                            </li>
                                        <?php endif;

                                        if ( ! empty( $options['contact_website'] ) ) : ?>
                                            <li class="address"><label><?php esc_html_e( 'Website:', 'firm-graphy-pro' ); ?></label>
                                                <span><a href="<?php echo esc_url( $options['contact_website'] ); ?>"><?php echo esc_html( $options['contact_website'] ); ?></a></span>
                                            </li>
                                        <?php endif; ?>
                                    </ul>
                                </div><!-- .entry-content -->

                                <?php if ( has_nav_menu( 'social' ) ) : ?>
                                    <div class="social-icons">
                                        <?php  
                                       /**
                                        * Displays a navigation menu.
                                        *
                                        * @since 3.0.0
                                        */
                                        
                                    
                                        wp_nav_menu( array(
                                            'theme_location' => 'social',
                                            'container' => 'false',
                                            'menu_class' => 'social-menu',
                                            'depth' => 1,
                                            'link_before' => '<span class="screen-reader-text">',
                                            'link_after' => '</span>',
                                        ) );
                                        ?>
                                    </div><!-- .social-icons -->
                                <?php endif; ?>
                            </div><!-- .contact-description -->
                        </div><!-- .hentry -->

                        <?php if ( ! empty( $options['contact_form'] ) ) : ?>
                            <div class="hentry">
                                <div class="contact-form">
                                    <?php echo do_shortcode( wp_kses_post( $options['contact_form'] ) ); ?>
                                </div><!-- .contact-form -->
                            </div><!-- .hentry -->
                        <?php endif; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #contact-us -->

    <?php }
endif;